==> triton_model_analyzer-1.13.0-py3-none-manylinux1_x86_64.whl: tests/mocks/mock_dcgm.py <==
# Copyright (c) 2020, NVIDIA CORPORATION. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from unittest.mock import patch, Mock, MagicMock

from .mock_dcgm_field_group_watcher import MockDCGMFieldGroupWatcherHelper
from .mock_dcgm_agent import MockDCGMAgent
from .mock_base import MockBase


class MockDCGM(MockBase):
    """
    Mocks dcgm_agent methods.
    """

    def _fill_patchers(self):
        patchers = self._patchers

        structs_imports_path = [
            'model_analyzer.monitor.dcgm.dcgm_monitor',
            'model_analyzer.device.gpu_device_factory'
        ]
        for import_path in structs_imports_path:
            patchers.append(
                patch(f'{import_path}.structs._dcgmInit', MagicMock()))

        dcgm_agent_imports_path = [
            'model_analyzer.monitor.dcgm.dcgm_monitor',
            'model_analyzer.device.gpu_device_factory'
        ]
        for import_path in dcgm_agent_imports_path:
            patchers.append(patch(f'{import_path}.dcgm_agent', MockDCGMAgent))

        patchers.append(
            patch(
                'model_analyzer.monitor.dcgm.dcgm_monitor.dcgm_field_helpers.DcgmFieldGroupWatcher',
                MockDCGMFieldGroupWatcherHelper,
            ))

==> triton_model_analyzer-1.27.0-py3-none-manylinux1_x86_64.whl: tests/mocks/mock_dcgm.py <==
# Copyright (c) 2020, NVIDIA CORPORATION. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from unittest.mock import patch, MagicMock

from .mock_dcgm_field_group_watcher import MockDCGMFieldGroupWatcherHelper
from .mock_dcgm_agent import MockDCGMAgent
from .mock_base import MockBase


class MockDCGM(MockBase):
    """
    Mocks dcgm_agent methods.
    """

    def _fill_patchers(self):
        patchers = self._patchers

        structs_imports_path = [
            'model_analyzer.monitor.dcgm.dcgm_monitor',
            'model_analyzer.device.gpu_device_factory'
        ]
        for import_path in structs_imports_path:
            patchers.append(
                patch(f'{import_path}.structs._dcgmInit', MagicMock()))

        dcgm_agent_imports_path = [
            'model_analyzer.monitor.dcgm.dcgm_monitor',
            'model_analyzer.device.gpu_device_factory'
        ]
        for import_path in dcgm_agent_imports_path:
            patchers.append(patch(f'{import_path}.dcgm_agent', MockDCGMAgent))

        patchers.append(
            patch(
                'model_analyzer.monitor.dcgm.dcgm_monitor.dcgm_field_helpers.DcgmFieldGroupWatcher',
                MockDCGMFieldGroupWatcherHelper,
            ))
